@@ -27,4 +27,14 @@ impl PushoverResponse {
             return Ok(data.ok().unwrap());
         }
     }
+
+    pub fn try_from_blocking_reqwest_response(response: reqwest::blocking::Response) -> Result<PushoverResponse, Box<dyn std::error::Error>> {
+        let data = response.json::<PushoverResponse>();
+
+        if data.is_err() {
+            return Err(Box::from(data.err().unwrap()))
+        } else {
+            return Ok(data.ok().unwrap());
+        }
+    }
 }
